{% extends "layout.html" %}
{% block title %}- Folder Edit {{ action_form.name.data }}{% endblock %}
{% block body %}
    <form method="post">
        {{ action_form.csrf_token }}

        <div class="field is-horizontal">
            <div class="field-body">
                <div class="field column is-5">
                    <div class="control is-expanded">
                        {{ action_form.name(class='input', placeholder='Name') }}
                    </div>
                </div>

                <div class="field column is-5">
                    <div class="control is-expanded">
                        {{ action_form.path(class='input', placeholder='Path') }}
                    </div>
                </div>

                <div class="field column">
                    <div class="control is-expanded">
                        <input class="button is-info" type="submit">
                    </div>
                </div>
            </div>
        </div>
    </form>
{% endblock %}
